@@ -1,5 +1,8 @@
 class Colors:
+    def __init__(self):
+        pass
+
     BLUE = '\033[94m'
     GREEN = '\033[92m'
     RED = '\033[91m'
-    END = '\033[0m'
\ No newline at end of file
+    END = '\033[0m'
