@@ -7,7 +7,8 @@ except Exception as err:
     from core.exception import AwdExceptions
     raise AwdExceptions(str(err))
 
-def Setlog():
+
+def setLog():
     fmt = logging.Formatter('%(asctime)s - %(message)s')
     logger = logging.getLogger("{}".format(sys.argv[0]))
     logger.setLevel(logging.DEBUG)
@@ -15,11 +16,7 @@ def Setlog():
     stream_handler.setLevel(logging.DEBUG)
     stream_handler.setFormatter(fmt)
 
-    try:
-        filesuffex = '.'.join(os.path.basename(sys.argv[0]).split('.')[:-1]) + '-'
-    except:
-        filesuffex = ''
-    file_handler = logging.FileHandler('/tmp/{0}{1}.log'.format(filesuffex,datetime.date.today().strftime('%Y%m%d')))
+    file_handler = logging.FileHandler('/tmp/{0}{1}.log'.format("AutoAwd", datetime.date.today().strftime('%Y%m%d')))
     file_handler.setLevel(logging.DEBUG)
     file_handler.setFormatter(fmt)
     logger.addHandler(stream_handler)
