@@ -14,11 +14,11 @@ class MSSQL:
 
     def __GetConnect(self):
         if not self.db:
-            AwdExceptions("请设置数据库信息 !")
+            raise AwdExceptions("请设置数据库信息 !")
         self.conn = pymssql.connect(host=self.host,user=self.user,password=self.pwd,database=self.db,charset="utf8")
         cur = self.conn.cursor()
         if not cur:
-            AwdExceptions("连接数据库失败 !")
+            raise AwdExceptions("连接数据库失败 !")
         else:
             return cur
 
